about summary refs log tree commit diff
path: root/Src/zsh.h
diff options
context:
space:
mode:
Diffstat (limited to 'Src/zsh.h')
-rw-r--r--Src/zsh.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/Src/zsh.h b/Src/zsh.h
index 173b89183..bff2aeb55 100644
--- a/Src/zsh.h
+++ b/Src/zsh.h
@@ -1080,11 +1080,12 @@ struct shfunc {
 
 struct funcstack {
     Funcstack prev;		/* previous in stack */
-    char *name;			/* name of function called */
+    char *name;			/* name of function/sourced file called */
     char *filename;		/* file function resides in */
     char *caller;		/* name of caller */
     zlong flineno;		/* line number in file */
     zlong lineno;		/* line offset from beginning of function */
+    int sourced;		/* type of entry is a sourced file */
 };
 
 /* node in list of function call wrappers */